@@ -297,6 +297,7 @@ sub launch_server {
    my $configure_server=$_[5]||
          sub { print "NO configure_server method defined!" };
    my $tag=$_[6]||'';
+   my $region=$_[7]||'';
    my $num=$cnt+1;
    my ($server_host_block,$handle,$hash,$output,$error,$inst)=('','','','','');
    foreach (0..2) {
@@ -329,7 +330,8 @@ sub launch_server {
    add_and_tag_server($server_type,$cnt,$inst,$tag);
    $main::aws->{$server_type}->[$cnt]->[1]=$handle;
    my ($stdout,$stderr,$exitcode)=('','','');
-   $configure_server->($server_type,$cnt,$selection,$server_host_block);
+   $configure_server->($server_type,$cnt,$selection,$server_host_block,
+                       $region);
 }
 
 our $aws_configure=sub {
@@ -1098,8 +1100,27 @@ sub new_user_amazon {
    } else {
       $identity_file=$pem_file=assist_user_to_upload_pemfile();
    }
-   $credentials_csv_path="/home/$ENV{SUDO_USER}" if exists
-      $ENV{SUDO_USER} && (-e "/home/$ENV{SUDO_USER}/credentials.csv");
+   if (exists $ENV{SUDO_USER} &&
+         (-e "/home/$ENV{SUDO_USER}/credentials.csv")) {
+      $credentials_csv_path="/home/$ENV{SUDO_USER}";
+   } else {
+      my $homedir='.';
+      my $username=&Net::FullAuto::FA_Core::username();
+      if (can_load(modules => { "File::HomeDir" => 0 })) {
+         $homedir=File::HomeDir->my_home;
+      } elsif (-r "/home/$username") {
+         $homedir="/home/$username";
+      }
+      open(RD,"$homedir/.aws/credentials");
+      while (my $line=<RD>) {
+         if ($line=~/^\s*aws_access_key_id\s*=\s*(\S+)/) {
+            $main::aws->{access_id}=$1;
+         } elsif ($line=~/^\s*aws_secret_access_key\s*=\s*(\S+)/) {
+            $main::aws->{secret_key}=$1;
+         }
+      }
+      close RD;
+   }
    if ($need_to_configure_aws &&
          (-e "$credentials_csv_path/credentials.csv")) {
       open(FH,"<$credentials_csv_path/credentials.csv");
