@@ -48,6 +48,7 @@ my $configure_gnusocial=sub {
    my $server_type=$_[0];
    my $cnt=$_[1];
    my $selection=$_[2]||'';
+   my $region=$_[4]||'';
    my $handle=$main::aws->{$server_type}->[$cnt]->[1];
    my ($stdout,$stderr)=('','');
    ($stdout,$stderr)=$handle->cmd("sudo yum -y update",'__display__');
@@ -55,6 +56,9 @@ my $configure_gnusocial=sub {
    ($stdout,$stderr)=$handle->cmd("sudo yum grouplist hidden",'__display__');
    ($stdout,$stderr)=$handle->cmd("sudo yum groups mark convert",
       '__display__');
+   ($stdout,$stderr)=$handle->cmd(
+      'sudo yum -y install cyrus-sasl-plain send-mail-cf m4 java java-devel',
+      '__display__');
    my $install_gnusocial=<<'END';
 
            o o    o .oPYo. ooooo    .oo o     o     o o    o .oPYo.
@@ -66,6 +70,7 @@ my $configure_gnusocial=sub {
            ........................................................
            ::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 
+
                            https://gnu.io/social/
 
                         ____ _   _ _   _     ____             _       _
@@ -448,7 +453,7 @@ END
       }
    }
    ($stdout,$stderr)=$handle->cmd("sudo /etc/init.d/mysql start",
-       '__display__');
+      '__display__');
 print "\n\n\n\n\n\n\nSTDERR=$stderr\n\n\n\n\n\n\n";
    if ($stderr) {
       ($stdout,$stderr)=$handle->cmd(
@@ -535,6 +540,9 @@ print "\n\n\n\n\n\n\nSTDERR=$stderr\n\n\n\n\n\n\n";
    ($stdout,$stderr)=$handle->cmd(
       "${sudo}sed -i \'s/;listen.mode = 0660/listen.mode = 0664/\' ".
       '/etc/php-fpm-5.5.d/www.conf');
+   ($stdout,$stderr)=$handle->cmd(
+      "${sudo}chgrp -Rv ec2-user /var/lib/php/5.5/session ".
+      '/var/lib/php/5.5/wsdlcache','__display__');
    ($stdout,$stderr)=$handle->cmd("${sudo}/etc/init.d/php-fpm start");
    ($stdout,$stderr)=$handle->cwd("/var/www/gnusocial");
    ($stdout,$stderr)=$handle->cmd("${sudo}chgrp -v ec2-user .");
@@ -546,7 +554,123 @@ print "\n\n\n\n\n\n\nSTDERR=$stderr\n\n\n\n\n\n\n";
       "${sudo}chmod -v a+w avatar background file",'__display__');
    ($stdout,$stderr)=$handle->cmd(
       "${sudo}chgrp -v ec2-user avatar background file",'__display__');
-      my $starting_hadoop=<<'END';
+   #
+   # echo-ing/streaming files over ssh can be tricky. Use echo -e
+   #          and replace these characters with thier HEX
+   #          equivalents (use an external editor for quick
+   #          search and replace - and paste back results.
+   #          use copy/paste or cat file and copy/paste results.):
+   #
+   #          !  -   \\x21
+   #          "  -   \\x22
+   #          $  -   \\x24
+   #
+   # https://www.lisenet.com/2014/ - bash approach to conversion
+   my ($hash,$output,$error)=('','','');
+   my $c="aws iam list-access-keys --user-name gnusocial_email";
+   ($hash,$output,$error)=run_aws_cmd($c);
+   $hash||={};
+   foreach my $hash (@{$hash->{AccessKeyMetadata}}) {
+      my $c="aws iam delete-access-key --access-key-id $hash->{AccessKeyId} ".
+            "--user-name gnusocial_email";
+      ($hash,$output,$error)=run_aws_cmd($c);
+   }
+   sleep 1;
+   $c="aws iam delete-user --user-name gnusocial_email";
+   ($hash,$output,$error)=run_aws_cmd($c);
+   $c="aws iam create-user --user-name gnusocial_email";
+   ($hash,$output,$error)=run_aws_cmd($c);
+   $c="aws iam create-access-key --user-name gnusocial_email";
+   ($hash,$output,$error)=run_aws_cmd($c);
+   $hash||={};
+   my $java_smtp_generator=<<END;
+import javax.crypto.Mac;
+import javax.crypto.spec.SecretKeySpec;
+import javax.xml.bind.DatatypeConverter;
+
+public class SesSmtpCredentialGenerator {
+
+       // From http://docs.aws.amazon.com/ses/latest/DeveloperGuide/smtp-credentials.html
+
+       private static final String KEY_ENV_VARIABLE = \\x22AWS_SECRET_ACCESS_KEY\\x22; // Put your AWS secret access key in this environment variable.
+       private static final String MESSAGE = \\x22SendRawEmail\\x22; // Used to generate the HMAC signature. Do not modify.
+       private static final byte VERSION =  0x02; // Version number. Do not modify.
+
+       public static void main(String[] args) {
+    	       	   	
+              // Get the AWS secret access key from environment variable AWS_SECRET_ACCESS_KEY.
+              String key = System.getenv(KEY_ENV_VARIABLE);         	  
+              if (key == null)
+              {
+                 System.out.println(\\x22Error: Cannot find environment variable AWS_SECRET_ACCESS_KEY.\\x22);  
+                 System.exit(0);
+              }
+   	    	       	   
+              // Create an HMAC-SHA256 key from the raw bytes of the AWS secret access key.
+              SecretKeySpec secretKey = new SecretKeySpec(key.getBytes(), \\x22HmacSHA256\\x22);
+
+              try {         	  
+                     // Get an HMAC-SHA256 Mac instance and initialize it with the AWS secret access key.
+                     Mac mac = Mac.getInstance(\\x22HmacSHA256\\x22);
+                     mac.init(secretKey);
+
+                     // Compute the HMAC signature on the input data bytes.
+                     byte[] rawSignature = mac.doFinal(MESSAGE.getBytes());
+
+                     // Prepend the version number to the signature.
+                     byte[] rawSignatureWithVersion = new byte[rawSignature.length + 1];               
+                     byte[] versionArray = {VERSION};                
+                     System.arraycopy(versionArray, 0, rawSignatureWithVersion, 0, 1);
+                     System.arraycopy(rawSignature, 0, rawSignatureWithVersion, 1, rawSignature.length);
+
+                     // To get the final SMTP password, convert the HMAC signature to base 64.
+                     String smtpPassword = DatatypeConverter.printBase64Binary(rawSignatureWithVersion);       
+                     System.out.println(smtpPassword);
+              } 
+              catch (Exception ex) {
+                     System.out.println(\\x22Error generating SMTP password: \\x22 + ex.getMessage());
+              }             
+       }
+}
+END
+   ($stdout,$stderr)=$handle->cmd(
+      "echo -e \"$java_smtp_generator\" > SesSmtpCredentialGenerator.java");
+   ($stdout,$stderr)=$handle->cmd("javac SesSmtpCredentialGenerator.java");
+   $handle->cmd_raw(
+      "export AWS_SECRET_ACCESS_KEY=$hash->{AccessKey}->{SecretAccessKey}");
+   my $smtppass='';
+   ($smtppass,$stderr)=$handle->cmd("java SesSmtpCredentialGenerator");
+print "SMTPPASS=$smtppass and STDERR=$stderr and $hash->{AccessKey}->{AccessKeyId} and SEC=$hash->{AccessKey}->{SecretAccessKey}\n";
+   use LWP::UserAgent;
+   use HTTP::Request::Common;
+   use IO::Socket::SSL qw();
+   my $Browser = LWP::UserAgent->new(
+      ssl_opts => {
+         SSL_verify_mode => IO::Socket::SSL::SSL_VERIFY_NONE,
+         verify_hostname => 0,
+      }
+   );
+   my $response = $Browser->post(
+      "https://$public_ip/install.php",
+      [
+         'sitename' => 'FullAuto',
+         'fancy' => 'enable',
+         'ssl' => 'always',
+         'host' => 'localhost',
+         'dbtype' => 'mysql',
+         'database' => 'gnusocial',
+         'dbusername' => 'gnusocial',
+         'dbpassword' => 'goodrandompassword',
+         'admin_nickname' => 'admin',
+         'admin_password' => 'admin',
+         'admin_password2' => 'admin',
+         'admin_email' => 'brian.kelly@fullauto.com',
+         'site_profile' => 'public',
+         'submit' => 'Submit',
+      ],
+   );
+   print $response->content;    
+   my $starting_gnusocial=<<'END';
 
 
 
@@ -560,6 +684,7 @@ print "\n\n\n\n\n\n\nSTDERR=$stderr\n\n\n\n\n\n\n";
      ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
      ::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 
+
                            https://gnu.io/social/
 
                         ____ _   _ _   _     ____             _       _
@@ -571,9 +696,26 @@ print "\n\n\n\n\n\n\nSTDERR=$stderr\n\n\n\n\n\n\n";
 
  (The Free Software Foundation is **NOT** a sponsor of the FullAuto© Project.)
 END
-   print $starting_hadoop;sleep 10;
+   print $starting_gnusocial;sleep 10;
+   $region=~s/^.*['](.*)[']$/$1/;
+   ($stdout,$stderr)=$handle->cmd('sudo wget -qO- '.
+      'http://docs.aws.amazon.com/ses/latest/DeveloperGuide/smtp-connect.html'
+      );
+   my @smtp_servers=();my $smtp_server='us-east-1';
+   foreach my $line (split /\n/,$stdout) {
+      if (-1<index $line,'email-smtp.') {
+         $line=~s/^.*(email-smtp\.[^Hh].*?com).*$/$1/;
+         next unless $line=~/^email-smtp/;
+         push @smtp_servers,$line;
+         if (-1<index $line,$region) {
+            $smtp_server=$line;
+            last;
+         }
+      }
+   }
+print "SMTP SERVER = $smtp_server\n";
    print "\n   ACCESS GNU SOCIAL UI AT:\n\n",
-         " https://$public_ip/install.php\n";
+         " https://$public_ip/index.php\n";
    my $thanks=<<'END';
 
      ______                  _    ,
@@ -589,7 +731,7 @@ END
           |_| \_|\___|\__|     |_|   \__,_|_|_/_/   \_\__,_|\__\___/ ©
 
 
-   Copyright © 2000-2015  Brian M. Kelly  Brian.Kelly@FullAuto.com
+   Copyright © 2000-2016  Brian M. Kelly  Brian.Kelly@FullAuto.com
 
 END
    eval {
@@ -611,6 +753,9 @@ my $standup_gnusocial=sub {
    $type=~s/^"//;
    $type=~s/"$//;
    $type=substr($type,0,(index $type,' ->')-3);
+   my $region="]T[{awsregions}";
+   $region=~s/^"//;
+   $region=~s/"$//;
    my $gnusocial="]T[{select_gnusocial_setup}";
    my $i=$main::aws->{fullauto}->{ImageId}||'';
    my $s=$main::aws->{fullauto}->
@@ -660,12 +805,12 @@ my $standup_gnusocial=sub {
          "--security-group-ids $g --subnet-id $s";
       if ($#{$main::aws->{'GNU.io/Social'}}==0) {
          launch_server('GNU.io/Social',$cnt,$gnusocial,'',$c,
-         $configure_gnusocial);
+         $configure_gnusocial,'',$region);
       } else {
          my $num=$#{$main::aws->{'GNU.io/Social'}}-1;
          foreach my $num (0..$num) {
             launch_server('GNU.io/Social',$cnt++,$gnusocial,'',$c,
-            $configure_gnusocial);
+            $configure_gnusocial,'',$region);
          }
       }
    }
@@ -764,6 +909,37 @@ END
 
 };
 
+our $gnusocial_enter_email_address=sub {
+
+   my @options=('GNU Social & MySQL & NGINX on 1 Server');
+   my $gnusocial_email_banner=<<'END';
+
+    ___     _             ___            _ _     _      _    _
+   | __|_ _| |_ ___ _ _  | __|_ __  __ _(_) |   /_\  __| |__| |_ _ ___ ______
+   | _|| ' \  _/ -_) '_| | _|| '  \/ _` | | |  / _ \/ _` / _` | '_/ -_|_-<_-<
+   |___|_||_\__\___|_|   |___|_|_|_\__,_|_|_| /_/ \_\__,_\__,_|_| \___/__/__/
+
+
+
+END
+   my %select_gnusocial_setup=(
+
+      Name => 'select_gnusocial_setup',
+      Item_1 => {
+
+         Text => ']C[',
+         Convey => \@options,
+         Result => $gnusocial_setup_summary,
+
+      },
+      Scroll => 1,
+      Banner => $gnusocial_email_banner,
+   );
+   return \%select_gnusocial_setup
+
+};
+
+
 our $select_gnusocial_setup=sub {
 
    my @options=('GNU Social & MySQL & NGINX on 1 Server');
@@ -793,7 +969,8 @@ END
 
          Text => ']C[',
          Convey => \@options,
-         Result => $gnusocial_setup_summary,
+         #Result => $gnusocial_setup_summary,
+         Result => $gnusocial_enter_email_address,
 
       },
       Scroll => 1,
